#!/bin/sh
# script for generating sample jobs

if test ! -z "$FAKE"; then
	SUFFIX="_fake"
fi
if [ `echo $(basename $0) | grep 'glite-lb-' | wc -l` = "1" ]; then
	PREFIX=glite-lb-
fi
LOGFD=${LOGFD:-2}
if [ -d `dirname $0`/../bin ]; then
	BINDIR=`dirname $0`/../bin
else
	BINDIR=`dirname $0`
fi
LOGEV=${LOGEV:-${BINDIR}/${PREFIX}logevent}${SUFFIX}
JOB_REG=${JOB_REG:-`dirname $0`/${PREFIX}job_reg}${SUFFIX}
EDG_JOBID=
LBPROXY=
LBPROXY_STORE_SOCK=
LARGE_STRESS=

usage()
{
	echo "Usage : $0 [-x | -X store_socket_path] [-m bkserver_machine_name][-j job_id][-l size_of_random_data]" 
	exit 4
}

# read parameters
while test -n "$1"
do
	case "$1" in 
	"-m") shift; BKSERVER_HOST="$1" ;;
	"-x") LBPROXY="-x" ;;
	"-X") shift; LBPROXY="-x"; LBPROXY_STORE_SOCK="-S $1" ;;
	"-j") shift; EDG_JOBID="$1" ;;
	"-l") shift; LARGE_STRESS="-l $1" ;;
	"*") usage ;;
	esac
	shift
done

test \( -z "$BKSERVER_HOST" \) -a \( -z "$EDG_JOBID" \) && usage

if [ -z "$EDG_JOBID" ] 
then
	# initial sequence code & jobid (normaly returned by job_reg)
	EDG_JOBID=
	SCRIPT=`$JOB_REG $LBPROXY -m $BKSERVER_HOST -s UserInterface | tail -n 2`
	eval $SCRIPT
	test -z "$EDG_JOBID" && exit 4
	echo EDG_JOBID=$EDG_JOBID
else
	test -z "$EDG_WL_SEQUENCE" && EDG_WL_SEQUENCE="UI=000003:NS=0000000000:WM=000000:BH=0000000000:JSS=000000:LM=000000:LRMS=000000:APP=000000:LBS=000000"
fi

send_log_ev()
{
	echo $LOGEV $LBPROXY $LBPROXY_STORE_SOCK -j "$EDG_JOBID" -c "$EDG_WL_SEQUENCE" "$@" 1>&$LOGFD
	EDG_WL_SEQUENCE=`$LOGEV $LARGE_STRESS $LBPROXY $LBPROXY_STORE_SOCK -j $EDG_JOBID -c $EDG_WL_SEQUENCE "$@" 2>/dev/null`
	test $? -ne 0 -o -z "$EDG_WL_SEQUENCE" && exit 4
	true
}

 DESTINATION=CE1/queue1
 CE_NODE=worker1
send_log_ev -s NetworkServer -e Accepted  --from="UserInterface"  --from_host="sending component hostname"  --from_instance="sending component instance"  --local_jobid="new jobId (Condor  Globus ...)"
send_log_ev -s NetworkServer -e EnQueued  --queue="destination queue"  --job="job description in receiver language"  --result=OK  --reason="detailed description of transfer"
send_log_ev -s WorkloadManager -e DeQueued  --queue="queue name"  --local_jobid="new jobId assigned by the receiving component" 
send_log_ev -s WorkloadManager -e HelperCall  --helper_name="name of the called component" --helper_params="parameters of the call"  --src_role=CALLING
send_log_ev -s WorkloadManager -e Match --dest_id="${DESTINATION:-destination CE/queue}"
send_log_ev -s WorkloadManager -e HelperReturn  --helper_name="name of the called component" --retval="returned data"  --src_role=CALLING
send_log_ev -s WorkloadManager -e EnQueued  --queue="destination queue"  --job="job description in receiver language"  --result=OK  --reason="detailed description of transfer"
send_log_ev -s JobController -e DeQueued  --queue="queue name"  --local_jobid="new jobId assigned by the receiving component"
send_log_ev -s JobController -e Transfer --destination="LRMS" --dest_host="destination hostname" --dest_instance="destination instance" --dest_jobid="job description in receiver language" --result=OK --reason="detailed description of transfer" --dest_jobid="destination internal jobid"
send_log_ev -s LogMonitor -e Accepted  --from="JobController"  --from_host="sending component hostname"  --from_instance="sending component instance"  --local_jobid="new jobId (Condor  Globus ...)"
send_log_ev -s LogMonitor -e Transfer --destination="LRMS" --dest_host="destination hostname" --dest_instance="destination instance" --dest_jobid="job description in receiver language" --result=OK --reason="detailed description of transfer" --dest_jobid="destination internal jobid"
send_log_ev -s LogMonitor -e Running --node="${CE_NODE:-worker node}"
send_log_ev -s LogMonitor  -e Done  --status_code=FAILED  --reason="reason for the change"  --exit_code=141
send_log_ev -s LogMonitor  -e Resubmission  --result=WILLRESUB  --reason="let's try again"  --tag=none
 DESTINATION=CE2/queue2
 CE_NODE=worker2
 RESUB=SHALLOW
send_log_ev -s LogMonitor -e EnQueued  --queue="wm_input.fl"  --job="job description in receiver language"  --result=OK  --reason="detailed description of transfer"
send_log_ev -s WorkloadManager -e DeQueued  --queue="wm_input.fl"  --local_jobid="WM_ID" 
send_log_ev -s WorkloadManager  -e Resubmission  --result=${RESUB:-WILLRESUB}  --reason="let's try again"  --tag=none
send_log_ev -s WorkloadManager -e HelperCall  --helper_name="name of the called component" --helper_params="parameters of the call"  --src_role=CALLING
send_log_ev -s WorkloadManager -e Match --dest_id="${DESTINATION:-destination CE/queue}"
send_log_ev -s WorkloadManager -e HelperReturn  --helper_name="name of the called component" --retval="returned data"  --src_role=CALLING
send_log_ev -s WorkloadManager -e EnQueued  --queue="wm_output.fl"  --job="job description in receiver language"  --result=OK  --reason="detailed description of transfer"
send_log_ev -s JobController -e DeQueued  --queue="wm_output.fl"  --local_jobid="JC_ID"
send_log_ev -s JobController -e Transfer --destination="LRMS" --dest_host="destination hostname" --dest_instance="destination instance" --dest_jobid="job description in receiver language" --result=OK --reason="detailed description of transfer" --dest_jobid="destination internal jobid"
send_log_ev -s LogMonitor -e Accepted  --from="JobController"  --from_host="sending component hostname"  --from_instance="sending component instance"  --local_jobid="new jobId (Condor  Globus ...)"
send_log_ev -s LogMonitor -e Transfer --destination="LRMS" --dest_host="destination hostname" --dest_instance="destination instance" --dest_jobid="job description in receiver language" --result=OK --reason="detailed description of transfer" --dest_jobid="destination internal jobid"
send_log_ev -s LogMonitor -e Running --node="${CE_NODE:-worker node}"
send_log_ev -s LogMonitor  -e Done  --status_code=FAILED  --reason="reason for the change"  --exit_code=141
send_log_ev -s LogMonitor  -e Resubmission  --result=WILLRESUB  --reason="let's try again"  --tag=none
 DESTINATION=CE3/queue3
 CE_NODE=worker3
 RESUB=SHALLOW
send_log_ev -s LogMonitor -e EnQueued  --queue="wm_input.fl"  --job="job description in receiver language"  --result=OK  --reason="detailed description of transfer"
send_log_ev -s WorkloadManager -e DeQueued  --queue="wm_input.fl"  --local_jobid="WM_ID" 
send_log_ev -s WorkloadManager  -e Resubmission  --result=${RESUB:-WILLRESUB}  --reason="let's try again"  --tag=none
send_log_ev -s WorkloadManager -e HelperCall  --helper_name="name of the called component" --helper_params="parameters of the call"  --src_role=CALLING
send_log_ev -s WorkloadManager -e Match --dest_id="${DESTINATION:-destination CE/queue}"
send_log_ev -s WorkloadManager -e HelperReturn  --helper_name="name of the called component" --retval="returned data"  --src_role=CALLING
send_log_ev -s WorkloadManager -e EnQueued  --queue="wm_output.fl"  --job="job description in receiver language"  --result=OK  --reason="detailed description of transfer"
send_log_ev -s JobController -e DeQueued  --queue="wm_output.fl"  --local_jobid="JC_ID"
send_log_ev -s JobController -e Transfer --destination="LRMS" --dest_host="destination hostname" --dest_instance="destination instance" --dest_jobid="job description in receiver language" --result=OK --reason="detailed description of transfer" --dest_jobid="destination internal jobid"
send_log_ev -s LogMonitor -e Accepted  --from="JobController"  --from_host="sending component hostname"  --from_instance="sending component instance"  --local_jobid="new jobId (Condor  Globus ...)"
send_log_ev -s LogMonitor -e Transfer --destination="LRMS" --dest_host="destination hostname" --dest_instance="destination instance" --dest_jobid="job description in receiver language" --result=OK --reason="detailed description of transfer" --dest_jobid="destination internal jobid"
send_log_ev -s LogMonitor -e Running --node="${CE_NODE:-worker node}"
send_log_ev -s LogMonitor  -e ReallyRunning  --wn_seq="$EDG_WL_SEQUENCE"
